public inbox for gcc-cvs@sourceware.org
help / color / mirror / Atom feed
* [gcc r14-319] Fortran: Fix (mostly) comment typos
@ 2023-04-28  7:24 Tobias Burnus
  0 siblings, 0 replies; only message in thread
From: Tobias Burnus @ 2023-04-28  7:24 UTC (permalink / raw)
  To: gcc-cvs

https://gcc.gnu.org/g:7ebd4a1d61993c0a75e9ff3098aded21ef04a4da

commit r14-319-g7ebd4a1d61993c0a75e9ff3098aded21ef04a4da
Author: Tobias Burnus <tobias@codesourcery.com>
Date:   Fri Apr 28 09:23:18 2023 +0200

    Fortran: Fix (mostly) comment typos
    
    Only other changes are fixing the variable name a(b)breviated_modproc_decl
    and a few typos in gfortran.texi.
    
    gcc/fortran/ChangeLog:
    
            * gfortran.texi: Fix typos.
            * decl.cc: Fix typos in comments and in a variable name.
            * arith.cc: Fix comment typos.
            * check.cc: Likewise.
            * class.cc: Likewise.
            * dependency.cc: Likewise.
            * expr.cc: Likewise.
            * frontend-passes.cc: Likewise.
            * gfortran.h: Likewise.
            * intrinsic.cc: Likewise.
            * iresolve.cc: Likewise.
            * match.cc: Likewise.
            * module.cc: Likewise.
            * primary.cc: Likewise.
            * resolve.cc: Likewise.
            * simplify.cc: Likewise.
            * trans-array.cc: Likewise.
            * trans-decl.cc: Likewise.
            * trans-expr.cc: Likewise.
            * trans-intrinsic.cc: Likewise.
            * trans-openmp.cc: Likewise.
            * trans-stmt.cc: Likewise.

Diff:
---
 gcc/fortran/arith.cc           |  2 +-
 gcc/fortran/check.cc           |  2 +-
 gcc/fortran/class.cc           |  2 +-
 gcc/fortran/decl.cc            | 24 ++++++++++++------------
 gcc/fortran/dependency.cc      |  2 +-
 gcc/fortran/expr.cc            |  2 +-
 gcc/fortran/frontend-passes.cc |  6 +++---
 gcc/fortran/gfortran.h         |  4 ++--
 gcc/fortran/gfortran.texi      |  8 ++++----
 gcc/fortran/intrinsic.cc       |  2 +-
 gcc/fortran/iresolve.cc        |  2 +-
 gcc/fortran/match.cc           |  2 +-
 gcc/fortran/module.cc          |  2 +-
 gcc/fortran/primary.cc         |  6 +++---
 gcc/fortran/resolve.cc         |  6 +++---
 gcc/fortran/simplify.cc        |  4 ++--
 gcc/fortran/trans-array.cc     |  4 ++--
 gcc/fortran/trans-decl.cc      |  2 +-
 gcc/fortran/trans-expr.cc      |  6 +++---
 gcc/fortran/trans-intrinsic.cc |  2 +-
 gcc/fortran/trans-openmp.cc    |  6 +++---
 gcc/fortran/trans-stmt.cc      | 10 +++++-----
 22 files changed, 53 insertions(+), 53 deletions(-)

diff --git a/gcc/fortran/arith.cc b/gcc/fortran/arith.cc
index ddf9874671c..d1d814b3ae1 100644
--- a/gcc/fortran/arith.cc
+++ b/gcc/fortran/arith.cc
@@ -1034,7 +1034,7 @@ gfc_arith_concat (gfc_expr *op1, gfc_expr *op2, gfc_expr **resultp)
   size_t len;
 
   /* By cleverly playing around with constructors, it is possible
-     to get mismaching types here.  */
+     to get mismatching types here.  */
   if (op1->ts.type != BT_CHARACTER || op2->ts.type != BT_CHARACTER
       || op1->ts.kind != op2->ts.kind)
     return ARITH_WRONGCONCAT;
diff --git a/gcc/fortran/check.cc b/gcc/fortran/check.cc
index 8c1ae8c2f00..b348bda6e6c 100644
--- a/gcc/fortran/check.cc
+++ b/gcc/fortran/check.cc
@@ -93,7 +93,7 @@ illegal_boz_arg (gfc_expr *x)
   return false;
 }
 
-/* Some precedures take two arguments such that both cannot be BOZ.  */
+/* Some procedures take two arguments such that both cannot be BOZ.  */
 
 static bool
 boz_args_check(gfc_expr *i, gfc_expr *j)
diff --git a/gcc/fortran/class.cc b/gcc/fortran/class.cc
index bffc0ffff3a..9d0c802b867 100644
--- a/gcc/fortran/class.cc
+++ b/gcc/fortran/class.cc
@@ -1631,7 +1631,7 @@ finalizer_insert_packed_call (gfc_code *block, gfc_finalizer *fini,
 
 
 /* Generate the finalization/polymorphic freeing wrapper subroutine for the
-   derived type "derived". The function first calls the approriate FINAL
+   derived type "derived". The function first calls the appropriate FINAL
    subroutine, then it DEALLOCATEs (finalizes/frees) the allocatable
    components (but not the inherited ones). Last, it calls the wrapper
    subroutine of the parent. The generated wrapper procedure takes as argument
diff --git a/gcc/fortran/dependency.cc b/gcc/fortran/dependency.cc
index 9117825ee6e..a648d5c7903 100644
--- a/gcc/fortran/dependency.cc
+++ b/gcc/fortran/dependency.cc
@@ -543,7 +543,7 @@ gfc_dep_difference (gfc_expr *e1, gfc_expr *e2, mpz_t *result)
   e1 = gfc_discard_nops (e1);
   e2 = gfc_discard_nops (e2);
 
-  /* Inizialize tentatively, clear if we don't return anything.  */
+  /* Initialize tentatively, clear if we don't return anything.  */
   mpz_init (*result);
 
   /* Case 1: c1 - c2 = c1 - c2, trivially.  */
diff --git a/gcc/fortran/expr.cc b/gcc/fortran/expr.cc
index 02028f993fd..b19e3647aa0 100644
--- a/gcc/fortran/expr.cc
+++ b/gcc/fortran/expr.cc
@@ -3656,7 +3656,7 @@ gfc_check_conformance (gfc_expr *op1, gfc_expr *op2, const char *optype_msgid, .
 /* Given an assignable expression and an arbitrary expression, make
    sure that the assignment can take place.  Only add a call to the intrinsic
    conversion routines, when allow_convert is set.  When this assign is a
-   coarray call, then the convert is done by the coarray routine implictly and
+   coarray call, then the convert is done by the coarray routine implicitly and
    adding the intrinsic conversion would do harm in most cases.  */
 
 bool
diff --git a/gcc/fortran/frontend-passes.cc b/gcc/fortran/frontend-passes.cc
index 90428982023..136a292807d 100644
--- a/gcc/fortran/frontend-passes.cc
+++ b/gcc/fortran/frontend-passes.cc
@@ -424,9 +424,9 @@ copy_walk_reduction_arg (gfc_constructor *c, gfc_expr *fn)
   return fcn;
 }
 
-/* Callback function for optimzation of reductions to scalars.  Transform ANY
+/* Callback function for optimization of reductions to scalars.  Transform ANY
    ([f1,f2,f3, ...]) to f1 .or. f2 .or. f3 .or. ..., with ANY, SUM and PRODUCT
-   correspondingly.  Handly only the simple cases without MASK and DIM.  */
+   correspondingly.  Handle only the simple cases without MASK and DIM.  */
 
 static int
 callback_reduction (gfc_expr **e, int *walk_subtrees ATTRIBUTE_UNUSED,
@@ -1455,7 +1455,7 @@ simplify_io_impl_do (gfc_code **code, int *walk_subtrees,
 }
 
 /* Optimize a namespace, including all contained namespaces.
-  flag_frontend_optimize and flag_fronend_loop_interchange are
+  flag_frontend_optimize and flag_frontend_loop_interchange are
   handled separately.  */
 
 static void
diff --git a/gcc/fortran/gfortran.h b/gcc/fortran/gfortran.h
index db77d24e8b5..a15ff90e228 100644
--- a/gcc/fortran/gfortran.h
+++ b/gcc/fortran/gfortran.h
@@ -1916,7 +1916,7 @@ typedef struct gfc_symbol
      = 1 if it has been resolved in resolve_symbol.  */
   unsigned resolve_symbol_called:2;
   /* Set if this is a module function or subroutine with the
-     abreviated declaration in a submodule.  */
+     abbreviated declaration in a submodule.  */
   unsigned abr_modproc_decl:1;
   /* Set if a previous error or warning has occurred and no other
      should be reported.  */
@@ -2191,7 +2191,7 @@ typedef struct gfc_namespace
   /* Set to 1 if namespace is an interface body with "IMPORT" used.  */
   unsigned has_import_set:1;
 
-  /* Set to 1 if the namespace uses "IMPLICT NONE (export)".  */
+  /* Set to 1 if the namespace uses "IMPLICIT NONE (export)".  */
   unsigned has_implicit_none_export:1;
 
   /* Set to 1 if resolved has been called for this namespace.
diff --git a/gcc/fortran/gfortran.texi b/gcc/fortran/gfortran.texi
index b96712987e1..7786d23265f 100644
--- a/gcc/fortran/gfortran.texi
+++ b/gcc/fortran/gfortran.texi
@@ -1407,7 +1407,7 @@ When omitted, the count is implicitly assumed to be one.
 To support legacy codes, GNU Fortran allows the comma separator
 to be omitted immediately before and after character string edit
 descriptors in @code{FORMAT} statements.  A comma with no following format
-decriptor is permited if the @option{-fdec-blank-format-item} is given on
+descriptor is permitted if the @option{-fdec-blank-format-item} is given on
 the command line. This is considered non-conforming code and is
 discouraged.
 
@@ -3893,7 +3893,7 @@ typedef enum caf_deregister_t {
 caf_deregister_t;
 @end verbatim
 
-Allows to specifiy the type of deregistration of a coarray object.  The
+Allows to specify the type of deregistration of a coarray object.  The
 @code{CAF_DEREGTYPE_COARRAY_DEALLOCATE_ONLY} flag is only allowed for
 allocatable components in derived type coarrays.
 
@@ -4858,7 +4858,7 @@ an error message; may be NULL.
 @item @emph{NOTES}
 This acts like an atomic add of one to the remote image's event variable.
 The statement is an image-control statement but does not imply sync memory.
-Still, all preceeding push communications of this image to the specified
+Still, all preceding push communications of this image to the specified
 remote image have to be completed before @code{event_wait} on the remote
 image returns.
 @end table
@@ -4903,7 +4903,7 @@ cores) followed by another waiting strategy such as a sleeping wait (possibly
 with an increasing number of sleep time) or, if possible, a futex wait.
 
 The statement is an image-control statement but does not imply sync memory.
-Still, all preceeding push communications of this image to the specified
+Still, all preceding push communications of this image to the specified
 remote image have to be completed before @code{event_wait} on the remote
 image returns.
 @end table
diff --git a/gcc/fortran/intrinsic.cc b/gcc/fortran/intrinsic.cc
index 1a26b7a571f..b5ef664eb33 100644
--- a/gcc/fortran/intrinsic.cc
+++ b/gcc/fortran/intrinsic.cc
@@ -3310,7 +3310,7 @@ add_functions (void)
   make_generic ("loc", GFC_ISYM_LOC, GFC_STD_GNU);
 
 
-  /* The next of intrinsic subprogram are the degree trignometric functions.
+  /* The next of intrinsic subprogram are the degree trigonometric functions.
      These were hidden behind the -fdec-math option, but are now simply
      included as extensions to the set of intrinsic subprograms.  */
 
diff --git a/gcc/fortran/iresolve.cc b/gcc/fortran/iresolve.cc
index 8acad60a02b..7880aba63bb 100644
--- a/gcc/fortran/iresolve.cc
+++ b/gcc/fortran/iresolve.cc
@@ -3104,7 +3104,7 @@ gfc_resolve_trim (gfc_expr *f, gfc_expr *string)
 }
 
 
-/* Resolve the degree trignometric functions.  This amounts to setting
+/* Resolve the degree trigonometric functions.  This amounts to setting
    the function return type-spec from its argument and building a
    library function names of the form _gfortran_sind_r4.  */
 
diff --git a/gcc/fortran/match.cc b/gcc/fortran/match.cc
index 5eb6d0e1c1d..d59daf5a581 100644
--- a/gcc/fortran/match.cc
+++ b/gcc/fortran/match.cc
@@ -5736,7 +5736,7 @@ gfc_match_equivalence (void)
 
   /* EQUIVALENCE has been matched.  After gobbling any possible whitespace,
      the next character needs to be '('.  Check that here, and return
-     MATCH_NO for a variable of the form equivalencej.  */
+     MATCH_NO for a variable of the form equivalence.  */
   gfc_gobble_whitespace ();
   c = gfc_peek_ascii_char ();
   if (c != '(')
diff --git a/gcc/fortran/module.cc b/gcc/fortran/module.cc
index 601497e0998..95fdda6b2aa 100644
--- a/gcc/fortran/module.cc
+++ b/gcc/fortran/module.cc
@@ -2419,7 +2419,7 @@ mio_symbol_attribute (symbol_attribute *attr)
 	  MIO_NAME (ab_attribute) (AB_OACC_ROUTINE_LOP_SEQ, attr_bits);
 	  break;
 	case OACC_ROUTINE_LOP_ERROR:
-	  /* ... intentionally omitted here; it's only unsed internally.  */
+	  /* ... intentionally omitted here; it's only used internally.  */
 	default:
 	  gcc_unreachable ();
 	}
diff --git a/gcc/fortran/primary.cc b/gcc/fortran/primary.cc
index 00d35a71770..077489ab96e 100644
--- a/gcc/fortran/primary.cc
+++ b/gcc/fortran/primary.cc
@@ -756,8 +756,8 @@ done:
     }
 
   /* Warn about trailing digits which suggest the user added too many
-     trailing digits, which may cause the appearance of higher pecision
-     than the kind kan support.
+     trailing digits, which may cause the appearance of higher precision
+     than the kind can support.
 
      This is done by replacing the rightmost non-zero digit with zero
      and comparing with the original value.  If these are equal, we
@@ -3060,7 +3060,7 @@ build_actual_constructor (gfc_structure_ctor_component **comp_head,
 		return false;
 	      value = gfc_get_null_expr (&gfc_current_locus);
 	    }
-	  /* ....(Preceeding sentence) If a component with default
+	  /* ....(Preceding sentence) If a component with default
 	     initialization has no corresponding component-data-source, then
 	     the default initialization is applied to that component.  */
 	  else if (comp->initializer)
diff --git a/gcc/fortran/resolve.cc b/gcc/fortran/resolve.cc
index 55d8e326a87..c3d508fb45d 100644
--- a/gcc/fortran/resolve.cc
+++ b/gcc/fortran/resolve.cc
@@ -5883,7 +5883,7 @@ resolve_variable (gfc_expr *e)
       /* Because this is an associate var and the first ref either is a ref to
 	 the _data component or not, no traversal of the ref chain is
 	 needed.  The array ref needs to be inserted after the _data ref,
-	 or when that is not present, which may happend for polymorphic
+	 or when that is not present, which may happened for polymorphic
 	 types, then at the first position.  */
       ref = e->ref;
       if (!ref)
@@ -6102,7 +6102,7 @@ resolve_procedure:
 	     the symbol in the expression and convert the array reference
 	     into an actual arglist if the old symbol is a variable; or
 	(ii) That in which an external function is typed but not declared
-	     explcitly to be external. Here, the old symbol is changed
+	     explicitly to be external. Here, the old symbol is changed
 	     from a variable to an external function.  */
 static bool
 check_host_association (gfc_expr *e)
@@ -11134,7 +11134,7 @@ resolve_ordinary_assign (gfc_code *code, gfc_namespace *ns)
       && (rhs->expr_type != EXPR_CONSTANT || !flag_dec_char_conversions))
     {
       /* Use of -fdec-char-conversions allows assignment of character data
-	 to non-character variables.  This not permited for nonconstant
+	 to non-character variables.  This not permitted for nonconstant
 	 strings.  */
       gfc_error ("Cannot convert %s to %s at %L", gfc_typename (rhs),
 		 gfc_typename (lhs), &rhs->where);
diff --git a/gcc/fortran/trans-array.cc b/gcc/fortran/trans-array.cc
index e1725808033..785cf504816 100644
--- a/gcc/fortran/trans-array.cc
+++ b/gcc/fortran/trans-array.cc
@@ -8588,7 +8588,7 @@ gfc_conv_array_parameter (gfc_se * se, gfc_expr * expr, bool g77,
 			 "Creating array temporary at %L", &expr->where);
 	}
 
-      /* When optmizing, we can use gfc_conv_subref_array_arg for
+      /* When optimizing, we can use gfc_conv_subref_array_arg for
 	 making the packing and unpacking operation visible to the
 	 optimizers.  */
 
@@ -11193,7 +11193,7 @@ gfc_alloc_allocatable_for_assignment (gfc_loopinfo *loop,
 }
 
 
-/* Initialize class descriptor's TKR infomation.  */
+/* Initialize class descriptor's TKR information.  */
 
 void
 gfc_trans_class_array (gfc_symbol * sym, gfc_wrapped_block * block)
diff --git a/gcc/fortran/trans-decl.cc b/gcc/fortran/trans-decl.cc
index 299764b08b2..18e2b8b78b4 100644
--- a/gcc/fortran/trans-decl.cc
+++ b/gcc/fortran/trans-decl.cc
@@ -7621,7 +7621,7 @@ gfc_generate_function_code (gfc_namespace * ns)
 	  desc = desc_p;
 	else if (!GFC_DESCRIPTOR_TYPE_P (TREE_TYPE (TREE_TYPE (desc_p))))
 	  {
-	    /* Character(len=*) explict-size/assumed-size array. */
+	    /* Character(len=*) explicit-size/assumed-size array. */
 	    desc = desc_p;
 	    gfc_build_qualified_array (desc, fsym);
 	  }
diff --git a/gcc/fortran/trans-expr.cc b/gcc/fortran/trans-expr.cc
index 09cdd9263c4..d902e8f3281 100644
--- a/gcc/fortran/trans-expr.cc
+++ b/gcc/fortran/trans-expr.cc
@@ -5596,7 +5596,7 @@ gfc_conv_gfc_desc_to_cfi_desc (gfc_se *parmse, gfc_expr *e, gfc_symbol *fsym)
     }
   gfc_add_block_to_block (&block, &se.pre);
 
-  /* Create array decriptor and set version, rank, attribute, type. */
+  /* Create array descriptor and set version, rank, attribute, type. */
   cfi = gfc_create_var (gfc_get_cfi_type (e->rank < 0
 					  ? GFC_MAX_DIMENSIONS : e->rank,
 					  false), "cfi");
@@ -5750,7 +5750,7 @@ gfc_conv_gfc_desc_to_cfi_desc (gfc_se *parmse, gfc_expr *e, gfc_symbol *fsym)
   if (e->ts.type == BT_ASSUMED)
     {
       /* Note: type(*) implies assumed-shape/assumed-rank if fsym requires
-	 an CFI descriptor.  Use the type in the descritor as it provide
+	 an CFI descriptor.  Use the type in the descriptor as it provide
 	 mode information. (Quality of implementation feature.)  */
       tree cond;
       tree ctype = gfc_get_cfi_desc_type (cfi);
@@ -8153,7 +8153,7 @@ gfc_trans_string_copy (stmtblock_t * block, tree dlength, tree dest,
   /* Wstringop-overflow appears at -O3 even though this warning is not
      explicitly available in fortran nor can it be switched off. If the
      source length is a constant, its negative appears as a very large
-     postive number and triggers the warning in BUILTIN_MEMSET. Fixing
+     positive number and triggers the warning in BUILTIN_MEMSET. Fixing
      the result of the MINUS_EXPR suppresses this spurious warning.  */
   tmp = fold_build2_loc (input_location, MINUS_EXPR,
 			 TREE_TYPE(dlen), dlen, slen);
diff --git a/gcc/fortran/trans-intrinsic.cc b/gcc/fortran/trans-intrinsic.cc
index 3cce9c0166e..e0c171d5f25 100644
--- a/gcc/fortran/trans-intrinsic.cc
+++ b/gcc/fortran/trans-intrinsic.cc
@@ -4126,7 +4126,7 @@ gfc_conv_intrinsic_minmax (gfc_se * se, gfc_expr * expr, enum tree_code op)
       tree calc;
       /* For floating point types, the question is what MAX(a, NaN) or
 	 MIN(a, NaN) should return (where "a" is a normal number).
-	 There are valid usecase for returning either one, but the
+	 There are valid use case for returning either one, but the
 	 Fortran standard doesn't specify which one should be chosen.
 	 Also, there is no consensus among other tested compilers.  In
 	 short, it's a mess.  So lets just do whatever is fastest.  */
diff --git a/gcc/fortran/trans-openmp.cc b/gcc/fortran/trans-openmp.cc
index 4ff9c59df5c..71f71235756 100644
--- a/gcc/fortran/trans-openmp.cc
+++ b/gcc/fortran/trans-openmp.cc
@@ -83,7 +83,7 @@ gfc_omp_is_optional_argument (const_tree decl)
 
 /* Check whether this DECL belongs to a Fortran optional argument.
    With 'for_present_check' set to false, decls which are optional parameters
-   themselve are returned as tree - or a NULL_TREE otherwise. Those decls are
+   themselves are returned as tree - or a NULL_TREE otherwise. Those decls are
    always pointers.  With 'for_present_check' set to true, the decl for checking
    whether an argument is present is returned; for arguments with value
    attribute this is the hidden argument and of BOOLEAN_TYPE.  If the decl is
@@ -6068,7 +6068,7 @@ gfc_add_clause_implicitly (gfc_omp_clauses *clauses_out,
 	    }
 	  if (n_firstp && n_lastp)
 	    {
-	      /* For parallel do, GCC puts firstprivatee/lastprivate
+	      /* For parallel do, GCC puts firstprivate/lastprivate
 		 on the parallel.  */
 	      if (is_parallel_do)
 		continue;
@@ -6635,7 +6635,7 @@ gfc_split_omp_clauses (gfc_code *code,
     clausesa[GFC_OMP_SPLIT_DO].nowait = true;
 
    /* Distribute allocate clause to do, parallel, distribute, teams, target
-      and taskloop.  The code below itereates over variables in the
+      and taskloop.  The code below iterates over variables in the
       allocate list and checks if that available is also in any
       privatization clause on those construct.  If yes, then we add it
       to the list of 'allocate'ed variables for that construct.  If a
diff --git a/gcc/fortran/trans-stmt.cc b/gcc/fortran/trans-stmt.cc
index 776f98d08d9..589f200162a 100644
--- a/gcc/fortran/trans-stmt.cc
+++ b/gcc/fortran/trans-stmt.cc
@@ -470,7 +470,7 @@ gfc_trans_call (gfc_code * code, bool dependency_check,
       gfc_conv_ss_startstride (&loop);
       /* TODO: gfc_conv_loop_setup generates a temporary for vector
 	 subscripts.  This could be prevented in the elemental case
-	 as temporaries are handled separatedly
+	 as temporaries are handled separately
 	 (below in gfc_conv_elemental_dependencies).  */
       if (code->expr1)
 	gfc_conv_loop_setup (&loop, &code->expr1->where);
@@ -2293,7 +2293,7 @@ trans_associate_var (gfc_symbol *sym, gfc_wrapped_block *block)
       gfc_init_se (&se, NULL);
       if (e->symtree->n.sym->ts.type == BT_CHARACTER)
 	{
-	  /* Deferred strings are dealt with in the preceeding.  */
+	  /* Deferred strings are dealt with in the preceding.  */
 	  gcc_assert (!e->symtree->n.sym->ts.deferred);
 	  tmp = e->symtree->n.sym->ts.u.cl->backend_decl;
 	}
@@ -4103,7 +4103,7 @@ gfc_trans_forall_loop (forall_info *forall_tmp, tree body,
 			      count, build_int_cst (TREE_TYPE (count), 0));
 
       /* PR 83064 means that we cannot use annot_expr_parallel_kind until
-       the autoparallelizer can hande this.  */
+       the autoparallelizer can handle this.  */
       if (forall_tmp->do_concurrent)
 	cond = build3 (ANNOTATE_EXPR, TREE_TYPE (cond), cond,
 		       build_int_cst (integer_type_node,
@@ -6351,7 +6351,7 @@ gfc_trans_allocate (gfc_code * code)
 		}
 	      /* Create a temp variable only for component refs to prevent
 		 having to go through the full deref-chain each time and to
-		 simplfy computation of array properties.  */
+		 simplify computation of array properties.  */
 	      temp_var_needed = TREE_CODE (se.expr) == COMPONENT_REF;
 	    }
 	}
@@ -6626,7 +6626,7 @@ gfc_trans_allocate (gfc_code * code)
 	  && DECL_P (expr3) && DECL_ARTIFICIAL (expr3))
 	{
 	  /* Build a temporary symtree and symbol.  Do not add it to the current
-	     namespace to prevent accidently modifying a colliding
+	     namespace to prevent accidentaly modifying a colliding
 	     symbol's as.  */
 	  newsym = XCNEW (gfc_symtree);
 	  /* The name of the symtree should be unique, because gfc_create_var ()

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2023-04-28  7:24 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2023-04-28  7:24 [gcc r14-319] Fortran: Fix (mostly) comment typos Tobias Burnus

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).
diff --git a/gcc/fortran/decl.cc b/gcc/fortran/decl.cc
index 233bf244d62..9c4b40d4ac4 100644
--- a/gcc/fortran/decl.cc
+++ b/gcc/fortran/decl.cc
@@ -1081,7 +1081,7 @@ char_len_param_value (gfc_expr **expr, bool *deferred)
   if (!gfc_expr_check_typed (*expr, gfc_current_ns, false))
     return MATCH_ERROR;
 
-  /* If gfortran gets an EXPR_OP, try to simplifiy it.  This catches things
+  /* If gfortran gets an EXPR_OP, try to simplify it.  This catches things
      like CHARACTER(([1])).   */
   if ((*expr)->expr_type == EXPR_OP)
     gfc_simplify_expr (*expr, 1);
@@ -1576,7 +1576,7 @@ gfc_verify_c_interop_param (gfc_symbol *sym)
 	    }
 
           /* Character strings are only C interoperable if they have a
-	     length of 1.  However, as an argument they are also iteroperable
+	     length of 1.  However, as an argument they are also interoperable
 	     when passed as descriptor (which requires len=: or len=*).  */
 	  if (sym->ts.type == BT_CHARACTER)
 	    {
@@ -2847,7 +2847,7 @@ variable_decl (int elem)
 	}
     }
 
   /* The dummy arguments and result of the abreviated form of MODULE
      PROCEDUREs, used in SUBMODULES should not be redefined.  */
   if (gfc_current_ns->proc_name
       && gfc_current_ns->proc_name->abr_modproc_decl)
@@ -3117,7 +3117,7 @@ variable_decl (int elem)
 	}
     }
 
-  /* Before adding a possible initilizer, do a simple check for compatibility
+  /* Before adding a possible initializer, do a simple check for compatibility
      of lhs and rhs types.  Assigning a REAL value to a derived type is not a
      good thing.  */
   if (current_ts.type == BT_DERIVED && initializer
@@ -8348,7 +8348,7 @@ gfc_match_end (gfc_statement *st)
   match m;
   gfc_namespace *parent_ns, *ns, *prev_ns;
   gfc_namespace **nsp;
-  bool abreviated_modproc_decl = false;
+  bool abbreviated_modproc_decl = false;
   bool got_matching_end = false;
 
   old_loc = gfc_current_locus;
@@ -8372,7 +8372,7 @@ gfc_match_end (gfc_statement *st)
       state = gfc_state_stack->previous->state;
       block_name = gfc_state_stack->previous->sym == NULL
 		 ? NULL : gfc_state_stack->previous->sym->name;
-      abreviated_modproc_decl = gfc_state_stack->previous->sym
+      abbreviated_modproc_decl = gfc_state_stack->previous->sym
 		&& gfc_state_stack->previous->sym->abr_modproc_decl;
       break;
 
@@ -8380,8 +8380,8 @@ gfc_match_end (gfc_statement *st)
       break;
     }
 
-  if (!abreviated_modproc_decl)
-    abreviated_modproc_decl = gfc_current_block ()
+  if (!abbreviated_modproc_decl)
+    abbreviated_modproc_decl = gfc_current_block ()
 			      && gfc_current_block ()->abr_modproc_decl;
 
   switch (state)
@@ -8395,7 +8395,7 @@ gfc_match_end (gfc_statement *st)
 
     case COMP_SUBROUTINE:
       *st = ST_END_SUBROUTINE;
-      if (!abreviated_modproc_decl)
+      if (!abbreviated_modproc_decl)
       target = " subroutine";
       else
 	target = " procedure";
@@ -8404,7 +8404,7 @@ gfc_match_end (gfc_statement *st)
 
     case COMP_FUNCTION:
       *st = ST_END_FUNCTION;
-      if (!abreviated_modproc_decl)
+      if (!abbreviated_modproc_decl)
       target = " function";
       else
 	target = " procedure";
@@ -8533,7 +8533,7 @@ gfc_match_end (gfc_statement *st)
 	{
 	  if (!gfc_notify_std (GFC_STD_F2008, "END statement "
 			       "instead of %s statement at %L",
-			       abreviated_modproc_decl ? "END PROCEDURE"
+			       abbreviated_modproc_decl ? "END PROCEDURE"
 			       : gfc_ascii_statement(*st), &old_loc))
 	    goto cleanup;
 	}
@@ -8551,7 +8551,7 @@ gfc_match_end (gfc_statement *st)
   /* Verify that we've got the sort of end-block that we're expecting.  */
   if (gfc_match (target) != MATCH_YES)
     {
-      gfc_error ("Expecting %s statement at %L", abreviated_modproc_decl
+      gfc_error ("Expecting %s statement at %L", abbreviated_modproc_decl
 		 ? "END PROCEDURE" : gfc_ascii_statement(*st), &old_loc);
       goto cleanup;
     }
@@ -2847,7 +2847,7 @@ variable_decl (int elem)
     }
 
-  /* The dummy arguments and result of the abreviated form of MODULE
+  /* The dummy arguments and result of the abbreviated form of MODULE
      PROCEDUREs, used in SUBMODULES should not be redefined.  */
   if (gfc_current_ns->proc_name
diff --git a/gcc/fortran/simplify.cc b/gcc/fortran/simplify.cc
index b65854c1021..7b0642126a9 100644
--- a/gcc/fortran/simplify.cc
+++ b/gcc/fortran/simplify.cc
@@ -4130,11 +4130,11 @@ simplify_bound_dim (gfc_expr *array, gfc_expr *kind, int d, int upper,
 	  /* For {L,U}BOUND, the value depends on whether the array
 	     is empty.  We can nevertheless simplify if the declared bound
 	     has the same value as that of an empty array, in which case
-	     the result isn't dependent on the array emptyness.  */
+	     the result isn't dependent on the array emptiness.  */
 	  if (mpz_cmp_si (declared_bound->value.integer, empty_bound) == 0)
 	    mpz_set_si (result->value.integer, empty_bound);
 	  else if (!constant_lbound || !constant_ubound)
 	    /* Array emptyness can't be determined, we can't simplify.  */
 	    goto returnNull;
 	  else if (mpz_cmp (l->value.integer, u->value.integer) > 0)
 	    mpz_set_si (result->value.integer, empty_bound);
@@ -4130,11 +4130,11 @@ simplify_bound_dim (gfc_expr *array, gfc_expr *kind, int d, int upper,
 	    mpz_set_si (result->value.integer, empty_bound);
 	  else if (!constant_lbound || !constant_ubound)
-	    /* Array emptyness can't be determined, we can't simplify.  */
+	    /* Array emptiness can't be determined, we can't simplify.  */
 	    goto returnNull;
 	  else if (mpz_cmp (l->value.integer, u->value.integer) > 0)